use bevy::{prelude::*, core_pipeline::tonemapping::Tonemapping};

fn main() {
    App::new()
        .add_plugins((
            DefaultPlugins,
        ))
        .add_systems(Startup, setup)
        .add_systems(Update, bevy::window::close_on_esc)
        .run();
}

fn setup(
    mut commands: Commands, 
    mut meshes: ResMut<Assets<Mesh>>,
    mut materials: ResMut<Assets<StandardMaterial>>,
) {
    let fog_color = Color::rgb(0.5, 0.5, 0.5);
    let material = materials.add(StandardMaterial { 
        base_color: Color::RED,
        unlit: true,
        ..default()
    });
    commands.spawn(PbrBundle {
        transform: Transform::from_xyz(0.0, 1.0, 0.0),
        mesh: meshes.add(Mesh::from(shape::Cube { size: 1.0 })),
        material: material.clone(),
        ..default()
    });
    commands.spawn(PbrBundle {
        mesh: meshes.add(shape::Plane::from_size(10.0).into()),
        material,
        ..default()
    });
    commands.spawn((
            Camera3dBundle {
            transform: Transform::from_xyz(0.0, 1.0, -5.0).looking_at(Vec3::new(0.0, 0.0, 0.0), Vec3::Y),
            tonemapping: Tonemapping::None,
            ..default()
        },
        FogSettings {
            color: fog_color,
            falloff: FogFalloff::Linear {
                start: 0.0,
                end: 10.0,
            },
            ..default()
        },
    ));
    commands.insert_resource(ClearColor(fog_color));
}
